@@ -25,6 +25,7 @@ from os import environ
 class WindowEglRpi(WindowBase):
 
     _rpi_dispmanx_id = int(environ.get("KIVY_BCM_DISPMANX_ID", "0"))
+    _rpi_dispmanx_layer = int(environ.get("KIVY_BCM_DISPMANX_LAYER", "0"))
 
     def create_window(self):
         bcm.host_init()
@@ -42,7 +43,8 @@ class WindowEglRpi(WindowBase):
         src = bcm.Rect(0, 0, w << 16, h << 16)
         display = egl.bcm_display_open(self._rpi_dispmanx_id)
         update = egl.bcm_update_start(0)
-        element = egl.bcm_element_add(update, display, 0, dst, src)
+        element = egl.bcm_element_add(
+            update, display, self._rpi_dispmanx_layer, dst, src)
         self.win = egl.NativeWindow(element, w, h)
         egl.bcm_update_submit_sync(update)
 
